@@ -35,6 +35,8 @@ PyXMLi rounds up line totals separately. This makes it easier for your customers
 to understand how you got to a total.
 '''
 def quantize(d, places=None):
+    if type(d) != Decimal:
+        d = Decimal(str(d))
     global PRECISION
     places = places or PRECISION
     return d.quantize(Decimal(str(10 ** -abs(places))),
@@ -565,17 +567,16 @@ class Invoice(ExtensibleXMLiElement):
         self.__payments = []
 
         super(Invoice, self).__init__()
+        self.__shipping = shipping
         if identifier:
             self.identifier = identifier
-        self.seller = seller
-        self.buyer = buyer
-        self.__shipping = shipping
         if name:
             self.name = name
-        if description:
-            self.description = description
         if currency:
             self.currency = currency
+        self.seller = seller
+        self.buyer = buyer
+        self.description = description
         self.status = status
         self.date = date
         self.due_date = due_date or (self.date if type(self.date) == date else
@@ -1435,16 +1436,6 @@ class Treatment(XMLiElement):
 
         self.__name = value
 
-    def __set_description(self, value):
-        '''
-        Sets the name of the treatment.
-        @param value:str
-        '''
-        if not value or not len(value):
-            raise ValueError("Invalid description.")
-
-        self.__description = value
-
     def __set_rate_type(self, value):
         '''
         Sets the rate type.
@@ -1466,7 +1457,6 @@ class Treatment(XMLiElement):
             raise ValueError("invalid rate value.")
 
     name = property(lambda self: self.__name, __set_name)
-    description = property(lambda self: self.__description, __set_description)
     rate_type = property(lambda self: self.__rate_type, __set_rate_type)
     interval = property(lambda self: self.__interval, __set_interval)
     rate = property(lambda self: self.__rate, __set_rate)
